<?php
/**
 * Astra Child Theme functions and definitions Developed By NagaTheme.com
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Astra Child
 * @since 1.0.0
 */

/**
 * Define Constants
 */
define( 'ASTRA_CHILD_VERSION', '1.0.0' );
define( 'ASTRA_CHILD_NAGA_URL', trailingslashit( get_stylesheet_directory_uri() ) );
define( 'ASTRA_CHILD_NAGA_LANG_URL', ASTRA_CHILD_NAGA_URL . 'languages/' );
define( 'WP_THEME_NAGA_URL', WP_LANG_DIR . '/themes/' );
define( 'WP_PLUGIN_NAGA_URL', WP_LANG_DIR . '/plugins/' );

// Denqueue styles - Avoid loading style.css of the child theme
add_action( 'wp_enqueue_scripts', 'child_dequeue_styles', 50 );
function child_dequeue_styles() {
	wp_dequeue_style( 'astra-child' );
}

// Load Child Theme Translations Itself
add_action( 'after_setup_theme', 'astra_child_theme_textdomain' );
function astra_child_theme_textdomain() {
	if ( is_rtl() ) {
		unload_textdomain( 'astra-child' );
		load_textdomain( 'astra-child', get_stylesheet_directory() . '/languages/astra-child-fa_IR.mo' );
	}
}

// Run the Astra Pro License Class
if ( ! class_exists( 'Astra_Pro_Zhk_SDK' ) ) {
	require_once 'includes/class-astra-pro-zhk-license.php';
}

// Load Admin CSS Styles
add_action( 'admin_enqueue_scripts', 'astra_child_naga_admin_styles' );
function astra_child_naga_admin_styles() {
	if ( Astra_Pro_Zhk_SDK::is_activated() === true ) {
		if ( is_rtl() ) {
			$path = ASTRA_CHILD_NAGA_URL . 'assets/css/naga-admin.css';
			wp_enqueue_style( 'naga-admin-css', $path );
		}
	}
}

// Load Front-End RTL CSS Styles
add_action( 'wp_enqueue_scripts', 'astra_child_naga_rtl_styles' );
function astra_child_naga_rtl_styles() {
	if ( Astra_Pro_Zhk_SDK::is_activated() === true ) {
		if ( is_rtl() ) {
			$path = ASTRA_CHILD_NAGA_URL . 'assets/css/rtl.min.css';
			wp_enqueue_style( 'astra-rtl', $path, array('astra-theme-css'), ASTRA_THEME_VERSION );
		}
	}
}

// Copy Translations As Content --- Astra Free Theme
add_action( 'admin_init', 'astra_free_naga_copy_translations' );
function astra_free_naga_copy_translations() {
	if ( Astra_Pro_Zhk_SDK::is_activated() === true ) {
		if ( is_rtl() ) {
			$locale = 'fa_IR';
			$domain = 'astra';
			$mofile = $domain . '-' . $locale . '.mo';
			$file1 = plugin_dir_path( __FILE__ ) . 'languages/' . $mofile;
			$file2 = WP_LANG_DIR . '/themes/' . $mofile;
			$contentx =@ file_get_contents( $file1 );
			$openedfile = fopen( $file2, "w" );
			fwrite( $openedfile, $contentx ) ;
			fclose( $openedfile );
			if ( $contentx !== FALSE ) {
				//var_dump("Text-Domain: $domain - Copied Successfully!");
			}
		}
	}
}

// Copy Translations As Content --- Brainstorm Force Plugins
add_action( 'admin_init', 'bsf_plugins_naga_copy_translations' );
function bsf_plugins_naga_copy_translations() {
	if ( Astra_Pro_Zhk_SDK::is_activated() === true ) {
		if ( is_rtl() ) {
			$locale = 'fa_IR';
			$domains = array (
				'astra-sites',
				'custom-fonts', 
				'astra-import-export',
				'sidebar-manager',
				'ultimate-addons-for-gutenberg'
			);
			foreach ( $domains as $domain) {
				$mofile = $domain . '-' . $locale . '.mo';
				$file1 = plugin_dir_path( __FILE__ ) . 'languages/' . $mofile;
				$file2 = WP_LANG_DIR . '/plugins/' . $mofile;
				$contentx =@ file_get_contents( $file1 );
				$openedfile = fopen( $file2, "w" );
				fwrite( $openedfile, $contentx ) ;
				fclose( $openedfile );
				if ( $contentx !== FALSE ) {
					//var_dump("Text-Domain: $domain - Copied Successfully!");
				}
			}
		}
	}
}

// Disable BrainStorm Force Notices
add_action( 'admin_init', 'astra_child_naga_disable_notices' );
function astra_child_naga_disable_notices() {
	if ( Astra_Pro_Zhk_SDK::is_activated() === true ) {
		$brainstrom = get_option( 'brainstrom_products' );
		$brainstrom['plugins']['astra-addon']['status'] = 'registered';
		$brainstrom['plugins']['astra-pro-sites']['status'] = 'registered';
		$brainstrom['plugins']['uael']['status'] = 'registered';
		$brainstrom['plugins']['uabb']['status'] = 'registered';
		$brainstrom['plugins']['convertpro']['status'] = 'registered';
		$brainstrom['plugins']['wp-schema-pro']['status'] = 'registered';
		$brainstrom['plugins']['astra-portfolio']['status'] = 'registered';
		update_option( 'brainstrom_products', $brainstrom );
	} else {
		remove_submenu_page( 'themes.php', 'starter-templates' );
		remove_submenu_page( 'themes.php', 'astra' );	// Astra Options
		remove_submenu_page( 'themes.php', 'edit.php?post_type=astra_adv_header' );
		remove_submenu_page( 'themes.php', 'edit.php?post_type=astra-advanced-hook' );
		remove_submenu_page( 'themes.php', 'edit.php?post_type=bsf-sidebar' );
		//remove_submenu_page( 'options-general.php', 'aiosrs_pro_admin_menu_page' );
		//remove_submenu_page( 'options-general.php', 'uae' );
		//remove_submenu_page( 'options-general.php', 'ubb' );
		//remove_menu_page( 'convert-pro' );
	}
}

// Naga Codes --- End